@@ -1,11 +1,16 @@
-bagger_bridge <- function(processed, base_model, seed, times, control, cost, ...) {
+bagger_bridge <- function(processed, weights, base_model, seed, times, control, cost, ...) {
   validate_outcomes_are_univariate(processed$outcomes)
   if (base_model %in% c("C5.0")) {
     validate_outcomes_are_factors(processed$outcomes)
   }
 
   dat <- as.data.frame(processed$predictors)
+  validate_case_weights(weights, processed$predictors)
+
   dat$.outcome <- processed$outcomes[[1]]
+  if (!is.null(weights)) {
+    dat$.weights <- weights
+  }
 
   set.seed(seed)
   rs <- rsample::bootstraps(dat, times = times) %>%
@@ -37,3 +42,16 @@ bagger_bridge <- function(processed, base_model, seed, times, control, cost, ...
     )
   res
 }
+
+validate_case_weights <- function(weights, data) {
+  if (is.null(weights)) {
+    return(invisible(NULL))
+  }
+  n <- nrow(data)
+  if (!is.vector(weights) || !is.numeric(weights) || length(weights) != n ||
+      any(weights < 0)) {
+    rlang::abort("'weights' should be a non-negative numeric vector with the same size as the data.")
+  }
+  invisible(NULL)
+}
+
